@@ -1,3 +1,8 @@
 ''' A telegram bot that applies watermark on images, gifs and videos. '''
 
-__version__ = "0.0.4"
+
+from telewater.main import start_bot
+
+__version__ = "0.0.6"
+
+# AAHNIK 2021
