@@ -1,3 +1,7 @@
+''' Various utility functions are defined in this module.
+'''
+
+
 import requests
 import shutil
 
@@ -16,6 +20,7 @@ import shutil
 
 def download_image(url: str, filename: str) -> bool:
     try:
+        print('Downloading image ... ')
         response = requests.get(url, stream=True)
         if response.status_code == 200:
             print('Got file response')
