@@ -1,7 +1,10 @@
+''' Watermark is applied here.
+'''
+
 import os
 
 
-def watermark(video_file: str, X_OFF: int = 10, Y_OFF: int = 10):
+def watermark_video(video_file: str, X_OFF: int = 10, Y_OFF: int = 10):
     output_file = f'watered_{video_file}'
     # TODO: allow time stamping in file names
     # TODO: allow the ffmpeg options to be customized by bot admins
@@ -17,4 +20,3 @@ def watermark(video_file: str, X_OFF: int = 10, Y_OFF: int = 10):
     print(command)
     os.system(command)
     return output_file
-
